==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/sagemaker_model/SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.java <==
package com.hashicorp.cdktf.providers.aws.sagemaker_model;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.518Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.sagemakerModel.SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig")
@software.amazon.jsii.Jsii.Proxy(SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_credentials_provider_arn SagemakerModel#repository_credentials_provider_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRepositoryCredentialsProviderArn();

    /**
     * @return a {@link Builder} of {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig> {
        java.lang.String repositoryCredentialsProviderArn;

        /**
         * Sets the value of {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig#getRepositoryCredentialsProviderArn}
         * @param repositoryCredentialsProviderArn Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_credentials_provider_arn SagemakerModel#repository_credentials_provider_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder repositoryCredentialsProviderArn(java.lang.String repositoryCredentialsProviderArn) {
            this.repositoryCredentialsProviderArn = repositoryCredentialsProviderArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig {
        private final java.lang.String repositoryCredentialsProviderArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.repositoryCredentialsProviderArn = software.amazon.jsii.Kernel.get(this, "repositoryCredentialsProviderArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.repositoryCredentialsProviderArn = java.util.Objects.requireNonNull(builder.repositoryCredentialsProviderArn, "repositoryCredentialsProviderArn is required");
        }

        @Override
        public final java.lang.String getRepositoryCredentialsProviderArn() {
            return this.repositoryCredentialsProviderArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("repositoryCredentialsProviderArn", om.valueToTree(this.getRepositoryCredentialsProviderArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.sagemakerModel.SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.Jsii$Proxy that = (SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.Jsii$Proxy) o;

            return this.repositoryCredentialsProviderArn.equals(that.repositoryCredentialsProviderArn);
        }

        @Override
        public final int hashCode() {
            int result = this.repositoryCredentialsProviderArn.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/sagemaker_model/SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.java <==
package com.hashicorp.cdktf.providers.aws.sagemaker_model;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.605Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.sagemakerModel.SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig")
@software.amazon.jsii.Jsii.Proxy(SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_model#repository_credentials_provider_arn SagemakerModel#repository_credentials_provider_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRepositoryCredentialsProviderArn();

    /**
     * @return a {@link Builder} of {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig> {
        java.lang.String repositoryCredentialsProviderArn;

        /**
         * Sets the value of {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig#getRepositoryCredentialsProviderArn}
         * @param repositoryCredentialsProviderArn Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/sagemaker_model#repository_credentials_provider_arn SagemakerModel#repository_credentials_provider_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder repositoryCredentialsProviderArn(java.lang.String repositoryCredentialsProviderArn) {
            this.repositoryCredentialsProviderArn = repositoryCredentialsProviderArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig {
        private final java.lang.String repositoryCredentialsProviderArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.repositoryCredentialsProviderArn = software.amazon.jsii.Kernel.get(this, "repositoryCredentialsProviderArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.repositoryCredentialsProviderArn = java.util.Objects.requireNonNull(builder.repositoryCredentialsProviderArn, "repositoryCredentialsProviderArn is required");
        }

        @Override
        public final java.lang.String getRepositoryCredentialsProviderArn() {
            return this.repositoryCredentialsProviderArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("repositoryCredentialsProviderArn", om.valueToTree(this.getRepositoryCredentialsProviderArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.sagemakerModel.SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.Jsii$Proxy that = (SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.Jsii$Proxy) o;

            return this.repositoryCredentialsProviderArn.equals(that.repositoryCredentialsProviderArn);
        }

        @Override
        public final int hashCode() {
            int result = this.repositoryCredentialsProviderArn.hashCode();
            return result;
        }
    }
}
